@@ -6,7 +6,7 @@ var panelScreen = panel.screen
 // For an Icons-Only Task Manager on the bottom, *3 is too much, *2 is too little
 // Round up to next highest even number since the Panel size widget only displays
 // even numbers
-panel.height = 44 // 2 * Math.ceil(gridUnit * 2.5 / 2)
+panel.height = 2 * Math.ceil(gridUnit * 2.5 / 2)
 
 // Restrict horizontal panel to a maximum size of a 21:9 monitor
 const maximumAspectRatio = 21/9;
